@@ -14,7 +14,7 @@ import (
 // Just prints out the output of git log as seen by git who.
 func dump(
 	revs []string,
-	paths []string,
+	pathspecs []string,
 	short bool,
 	since string,
 	until string,
@@ -31,8 +31,8 @@ func dump(
 		"called revs()",
 		"revs",
 		revs,
-		"paths",
-		paths,
+		"pathspecs",
+		pathspecs,
 		"short",
 		short,
 		"since",
@@ -57,12 +57,24 @@ func dump(
 		Nauthors: nauthors,
 	}
 
-	var subprocess *git.Subprocess
-	if short {
-		subprocess, err = git.RunLog(ctx, revs, paths, filters, false)
-	} else {
-		subprocess, err = git.RunLog(ctx, revs, paths, filters, true)
+	gitRootPath, err := git.GetRoot()
+	if err != nil {
+		return err
 	}
+
+	repoFiles, err := git.CheckRepoConfigFiles(gitRootPath)
+	if err != nil {
+		return err
+	}
+
+	subprocess, err := git.RunLog(
+		ctx,
+		revs,
+		pathspecs,
+		filters,
+		!short,
+		repoFiles.HasMailmap(),
+	)
 	if err != nil {
 		return err
 	}
